Learn R Programming

shrinkDSM (version 1.0.0)

gastric: Survival times of gastric cancer patients

Description

A data set of survival times of patients with locally advanced, nonresectable gastric carcinoma. The patients were either treated with chemotherapy plus radiation or chemotherapy alone.

Usage

gastric

Arguments

Format

A data frame with 90 rows and 4 variables:

id

patient id

radiation

dummy variable indicating which treatment was employed, 0 = chemotherapy, 1 = combined chemotherapy/radiation

time

time survived by patient in days

status

dummy variable indicating whether death of the patient was observed, 0 = death not observed (i.e. censored), 1 = death observed.